@@ -311,12 +311,28 @@ void KviSSL::shutdown()
 	}
 }
 
+/**
+ * Used only during passive (server) mode
+ * Check the client certificate, always valid, even if it not exists
+ */
+int verify_clientCallback(int preverify_ok, X509_STORE_CTX *x509_ctx) {
+	// From man page: If verify_callback returns 1, the verification process is continued. If verify_callback always returns 1,
+	// the TLS/SSL handshake will not be terminated with respect to verification failures and the connection will be established.
+	return 1;
+}
 
 bool KviSSL::initContext(Method m)
 {
 	if(m_pSSL)return false;
 	m_pSSLCtx = SSL_CTX_new(m == Client ? SSLv23_client_method() : SSLv23_server_method());
 	if(!m_pSSLCtx)return false;
+
+	if (m == Server)
+	{
+		// we have to request the peer certificate, else only the client can see the peer identity, not the server
+		SSL_CTX_set_verify(m_pSSLCtx, SSL_VERIFY_PEER, verify_clientCallback);
+	} 
+	
 	// we want all ciphers to be available here, except insecure ones, orderer by strength;
 	// ADH are moved to the end since they are less secure, but they don't need a certificate
 	// (so we can use secure dcc without a cert)
@@ -354,7 +370,8 @@ KviSSL::Result KviSSL::useCertificateFile(const char * cert,const char * pass)
 	X509 * x509 = 0;
 
 	FILE * f = fopen(cert,"r");
-	if(!f)return FileIoError;
+	if(!f)
+		return FileIoError;
 
 //	debug("READING CERTIFICATE %s",cert);
 	if(PEM_read_X509(f,&x509,cb,&m_szPass))
@@ -362,8 +379,10 @@ KviSSL::Result KviSSL::useCertificateFile(const char * cert,const char * pass)
 		if(!SSL_CTX_use_certificate(m_pSSLCtx,x509))
 		{
 			X509_free(x509);
+			fclose(f);
 			return SSLError;
 		}
+		X509_free(x509);
 	}
 
 	fclose(f);
@@ -380,7 +399,8 @@ KviSSL::Result KviSSL::usePrivateKeyFile(const char * key,const char * pass)
 	EVP_PKEY * k = 0;
 
 	FILE * f = fopen(key,"r");
-	if(!f)return FileIoError;
+	if(!f)
+		return FileIoError;
 
 //	debug("READING KEY %s",key);
 	if(PEM_read_PrivateKey(f,&k,cb,&m_szPass))
@@ -388,8 +408,10 @@ KviSSL::Result KviSSL::usePrivateKeyFile(const char * key,const char * pass)
 		if(!SSL_CTX_use_PrivateKey(m_pSSLCtx,k))
 		{
 			EVP_PKEY_free(k);
+			fclose(f);
 			return SSLError;
 		}
+		EVP_PKEY_free(k);
 	}
 
 	fclose(f);
