@@ -73,7 +73,6 @@
 #include "kvi_useridentity.h"
 #include "kvi_ircview.h"
 #include "kvi_animatedpixmapcache.h"
-#include "kvi_env.h"
 
 #ifndef COMPILE_NO_IPC
 	#include "kvi_ipc.h"
@@ -182,13 +181,6 @@ KviApp::KviApp(int &argc,char ** argv)
 	setOrganizationDomain("kvirc.net");
 	setOrganizationName("KVIrc");
 
-#ifdef COMPILE_ON_MAC
-	// Disable the native menubar on MacOSX as in Qt 4.6 it's quite buggy and
-	// *very* often crashes in QMenuBar::macUpdateMenuBar()->QAction::isVisible().
-	// FIXME: Check it with later Qt versions
-	kvi_setenv("QT_MAC_NO_NATIVE_MENUBAR","1");
-#endif //COMPILE_ON_MAC
-
 	// Ok...everything begins here
 	g_pApp                  = this;
 	m_szConfigFile          = QString();
@@ -787,7 +779,7 @@ void KviApp::checkSuggestRestoreDefaultScript()
 		__tr2qs("<b>Ooops...</b><br><br>" \
 				"<b>There are some reasons that make me think that your KVIrc installation is incomplete.</b><br><br>" \
 				"I might be wrong, but you seem to miss some of the features that the default KVIrc script provides." \
-				"This may happen because you have upgraded to an unstable cvs version, " \
+				"This may happen because you have upgraded to an unstable svn version, " \
 				"because you have accidentally deleted or damaged your configuration files, " \
 				"because you have installed an incomplete script " \
 				"or because you have hit a bug in KVIrc.<br><br>" \
