@@ -503,15 +503,17 @@ void KviFrame::addWindow(KviWindow *wnd,bool bShow)
 			} else {
 				wnd->setGeometry(rect);
 				wnd->triggerCreationEvents();
+				
 				if(bShow)
 				{
-					wnd->show();
 					if(bMaximized)
 						wnd->maximize();
 				} else {
+					wnd->setWindowState(wnd->windowState() | Qt::WindowMinimized);
 					if(bMaximized)
 						wnd->setWindowState(wnd->windowState() | Qt::WindowMaximized);
 				}
+				wnd->show();
 				wnd->youAreUndocked();
 				if(bShow)
 				{
@@ -825,6 +827,12 @@ void KviFrame::resizeEvent(QResizeEvent *e)
 	KviTalMainWindow::resizeEvent(e);
 }
 
+
+void KviFrame::contextMenuEvent(QContextMenuEvent *)
+{
+	// do nothing! avoids builtin popup from qmainwindow
+}
+
 void KviFrame::updatePseudoTransparency()
 {
 #ifdef COMPILE_PSEUDO_TRANSPARENCY
