@@ -915,7 +915,7 @@ void KviInputEditor::cut()
 	pClip->setText(m_szTextBuffer.mid(m_iSelectionBegin,(m_iSelectionEnd-m_iSelectionBegin)+1),QClipboard::Clipboard);
 
 	addCommand(Command(SetSelection, m_iCursorPosition, 0, m_iSelectionBegin, m_iSelectionEnd));
-	addCommand (Command(DeleteSelection, m_iCursorPosition, m_szTextBuffer.mid(m_iSelectionBegin, m_iSelectionEnd-m_iSelectionBegin+1), -1, -1));
+	addCommand (Command(DeleteSelection, m_iSelectionBegin, m_szTextBuffer.mid(m_iSelectionBegin, m_iSelectionEnd-m_iSelectionBegin+1), -1, -1));
 
 	m_szTextBuffer.remove(m_iSelectionBegin,(m_iSelectionEnd-m_iSelectionBegin)+1);
 	moveCursorTo(m_iSelectionBegin,false);
@@ -1149,6 +1149,11 @@ void KviInputEditor::returnPressed(bool)
 		m_pHistory->insert(0,new QString(m_szTextBuffer));
 	}
 
+	//ensure the color window is hidden (bug #835)
+	if(g_pColorWindow)
+		if(g_pColorWindow->isVisible())
+			g_pColorWindow->hide();
+
 	__range_valid(KVI_INPUT_MAX_LOCAL_HISTORY_ENTRIES > 1); //ABSOLUTELY NEEDED, if not, pHist will be destroyed...
 	if(m_pHistory->count() > KVI_INPUT_MAX_LOCAL_HISTORY_ENTRIES)m_pHistory->removeLast();
 
@@ -2236,6 +2241,11 @@ void KviInputEditor::sendPlain()
 {
 	if(m_pInputParent->inherits("KviInput"))
 	{
+		//ensure the color window is hidden (bug #835)
+		if(g_pColorWindow)
+			if(g_pColorWindow->isVisible())
+				g_pColorWindow->hide();
+
 		QString szBuffer(m_szTextBuffer);
 		m_szTextBuffer="";
 		selectOneChar(-1);
