@@ -327,7 +327,6 @@ void KviScriptEditorWidget::keyPressEvent(QKeyEvent * e)
 				return;
 			case Qt::Key_Enter:
 			case Qt::Key_Return:
-			case Qt::Key_Backspace:
 			case Qt::Key_PageUp:
 				 e->ignore(); // allow the parent to process it
 				 return;
@@ -718,6 +717,7 @@ void KviScriptEditorSyntaxHighlighter::highlightBlock(const QString & szText)
 KviScriptEditorImplementation::KviScriptEditorImplementation(QWidget * par)
 :KviScriptEditor(par)
 {
+	m_pOptionsDialog=0;
 	if(g_pScriptEditorWindowList->isEmpty())loadOptions();
 	g_pScriptEditorWindowList->append(this);
 	m_lastCursorPos = 0;
@@ -772,6 +772,11 @@ KviScriptEditorImplementation::KviScriptEditorImplementation(QWidget * par)
 
 KviScriptEditorImplementation::~KviScriptEditorImplementation()
 {
+	if(m_pOptionsDialog)
+	{
+		m_pOptionsDialog->deleteLater();
+		m_pOptionsDialog=0;
+	}
 	g_pScriptEditorWindowList->removeRef(this);
 	if(g_pScriptEditorWindowList->isEmpty())
 		saveOptions();
@@ -963,8 +968,17 @@ void KviScriptEditorImplementation::loadFromFile()
 
 void KviScriptEditorImplementation::configureColors()
 {
-	KviScriptEditorWidgetColorOptions dlg(this);
-	if(dlg.exec() == QDialog::Accepted)
+	if(!m_pOptionsDialog)
+	{
+		m_pOptionsDialog = new KviScriptEditorWidgetColorOptions(this);
+		connect(m_pOptionsDialog,SIGNAL(finished(int)),this,SLOT(optionsDialogFinished(int)));
+	}
+	m_pOptionsDialog->show();
+}
+
+void KviScriptEditorImplementation::optionsDialogFinished(int iResult)
+{
+	if(iResult == QDialog::Accepted)
 	{
 		m_pEditor->updateOptions();
 		saveOptions();
