@@ -412,16 +412,29 @@ KVSO_CLASS_FUNCTION(socket,read)
 			c->warning(__tr2qs_ctx("Buffer parameter is not an object","objects"));
 			return true;
 		}
-		if (!pObject->inheritsClass("memorybuffer"))
+		if (pObject->inheritsClass("memorybuffer"))
+		{
+			QByteArray *pBuffer=((KviKvsObject_memorybuffer *)pObject)->pBuffer();
+			int oldsize=pBuffer->size();
+			pBuffer->resize(oldsize+uLen);
+			kvi_memmove(pBuffer->data()+oldsize,m_pInBuffer,uLen);
+
+		}
+		else if (pObject->inheritsClass("file"))
+		{
+			KviFile *pFile=((KviKvsObject_file *)pObject)->file();
+			if (!pFile->isOpen())
+			{
+				c->warning(__tr2qs_ctx("File is not open!","objects"));
+				return true;
+			}
+			pFile->write(m_pInBuffer,uLen);
+		}
+		else
 		{
 			c->warning(__tr2qs_ctx("Buffer parameter is not a memorybuffer object","objects"));
 			return true;
 		}
-
-		QByteArray *pBuffer=((KviKvsObject_memorybuffer *)pObject)->pBuffer();
-		int oldsize=pBuffer->size();
-		pBuffer->resize(oldsize+uLen);
-		kvi_memmove(pBuffer->data()+oldsize,m_pInBuffer,uLen);
 		eatInData(uLen);
 		return true;
 	}
@@ -441,6 +454,7 @@ KVSO_CLASS_FUNCTION(socket,read)
 }
 
 
+
 KVSO_CLASS_FUNCTION(socket,write)
 {
 	kvs_uint_t uLen;
@@ -883,8 +897,9 @@ debug ("Socket created");
 	if(m_sock == KVI_INVALID_SOCKET)
 	{
 		unsigned int uOldConnectionId = m_uConnectionId;
-		callFunction(this,"connectFailedEvent",new KviKvsVariantList(
-			new KviKvsVariant(__tr2qs_ctx("Failed to create the socket","objects"))));
+		KviKvsVariantList lParams;
+		lParams.append(new KviKvsVariant(__tr2qs_ctx("Failed to create the socket","objects")));
+		callFunction(this,"connectFailedEvent",&lParams);
 		if(m_uConnectionId == uOldConnectionId)reset();
 		// else it has already been called!
 		return;
@@ -894,9 +909,9 @@ debug ("Socket created");
 	if(!kvi_socket_setNonBlocking(m_sock))
 	{
 		unsigned int uOldConnectionId = m_uConnectionId;
-
-		callFunction(this,"connectFailedEvent",new KviKvsVariantList(
-			new KviKvsVariant(__tr2qs_ctx("Failed to setup a nonblocking socket","objects"))));
+		KviKvsVariantList lParams;
+		lParams.append(new KviKvsVariant(__tr2qs_ctx("Failed to setup a nonblocking socket","objects")));
+		callFunction(this,"connectFailedEvent",&lParams);
 		if(m_uConnectionId == uOldConnectionId)reset();
 		// else it has already been called!
 		return;
@@ -920,8 +935,9 @@ debug ("Socket created");
 			QString callBackError=__tr2qs_ctx("Connect failure: ","objects");
 
 			callBackError.append((KviError::getDescription(KviError::translateSystemError(sockError)).toUtf8().data()));
-			callFunction(this,"connectFailedEvent",new KviKvsVariantList(new KviKvsVariant(callBackError)));
-
+			KviKvsVariantList lParams;
+			lParams.append(new KviKvsVariant(callBackError));
+			callFunction(this,"connectFailedEvent",&lParams);
 			if(m_uConnectionId == uOldConnectionId)reset();
 			// else it has already been called!
 			return;
@@ -942,9 +958,9 @@ debug ("Socket created");
 void KviKvsObject_socket::connectTimeoutSlot()
 {
 	unsigned int uOldConnectionId = m_uConnectionId;
-
-	callFunction(this,"connectFailedEvent",new KviKvsVariantList(
-				new KviKvsVariant(__tr2qs_ctx("Connect attempt timed out","objects"))));
+	KviKvsVariantList lParams;
+	lParams.append(new KviKvsVariant(__tr2qs_ctx("Connect attempt timed out","objects")));
+	callFunction(this,"connectFailedEvent",&lParams);
 	if(m_uConnectionId == uOldConnectionId)reset();
 	// else it has already been called!
 }
@@ -971,9 +987,9 @@ void KviKvsObject_socket::lookupRemoteIp()
 	if(!m_pDns->lookup(m_szRemoteIp,KviDns::Any))
 	{
 		unsigned int uOldConnectionId = m_uConnectionId;
-
-		callFunction(this,"connectFailedEvent",new KviKvsVariantList(
-				new KviKvsVariant(__tr2qs_ctx("Can't start the DNS thread","objects"))));
+		KviKvsVariantList lParams;
+		lParams.append(new KviKvsVariant(__tr2qs_ctx("Can't start the DNS thread","objects")));
+		callFunction(this,"connectFailedEvent",&lParams);
 		if(m_uConnectionId == uOldConnectionId)reset();
 		// else it has already been called!
 	}
@@ -985,9 +1001,9 @@ void KviKvsObject_socket::lookupDone(KviDns *pDns)
 	if(pDns->state() != KviDns::Success)
 	{
 		unsigned int uOldConnectionId = m_uConnectionId;
-
-		callFunction(this,"connectFailedEvent",new KviKvsVariantList(
-			new KviKvsVariant(KviError::getDescription(pDns->error()))));
+		KviKvsVariantList lParams;
+		lParams.append(new KviKvsVariant(KviError::getDescription(pDns->error())));
+		callFunction(this,"connectFailedEvent",&lParams);
 
 		if(m_uConnectionId == uOldConnectionId)reset();
 		// else it has already been called!
@@ -1026,8 +1042,9 @@ void KviKvsObject_socket::writeNotifierFired(int)
 		if(sockError > 0)sockError = KviError::translateSystemError(sockError);
 		else sockError = KviError_unknownError; //Error 0 ?
 		unsigned int uOldConnectionId = m_uConnectionId;
-		callFunction(this,"connectFailedEvent",new KviKvsVariantList(
-			new KviKvsVariant(KviError::getDescription(sockError))));
+		KviKvsVariantList lParams;
+		lParams.append(new KviKvsVariant(KviError::getDescription(sockError)));
+		callFunction(this,"connectFailedEvent",&lParams);
 		if(m_uConnectionId == uOldConnectionId)reset();
 		// else it has already been called!
 	} else {
@@ -1094,11 +1111,13 @@ void KviKvsObject_socket::readNotifierFired(int)
 
 				{
 					//	QString error=KviError::translateSystemError(err);
-						callFunction(this,"disconnectEvent",new KviKvsVariantList(
-						new KviKvsVariant((kvs_int_t)KviError::translateSystemError(err))));
+						KviKvsVariantList lParams;
+						lParams.append(new KviKvsVariant((kvs_int_t)KviError::translateSystemError(err)));
+						callFunction(this,"disconnectEvent",&lParams);
 				} else {
-						callFunction(this,"disconnectEvent",new KviKvsVariantList(
-						new KviKvsVariant(KviError::getDescription(KviError_remoteEndClosedConnection))));
+						KviKvsVariantList lParams;
+						lParams.append(new KviKvsVariant(KviError::getDescription(KviError_remoteEndClosedConnection)));
+						callFunction(this,"disconnectEvent",&lParams);
 
 				}
 				if(m_uConnectionId == uOldConnectionId)reset();
@@ -1113,13 +1132,16 @@ void KviKvsObject_socket::readNotifierFired(int)
 
 
 	unsigned int uOldConnectionId = m_uConnectionId;
-	callFunction(this,"dataAvailableEvent",new KviKvsVariantList(new KviKvsVariant((kvs_int_t)readLength)));
+	KviKvsVariantList lParams;
+	lParams.append(new KviKvsVariant((kvs_int_t)readLength));
+	callFunction(this,"dataAvailableEvent",&lParams);
 	if(m_uConnectionId == uOldConnectionId)
 	{
 		if(m_uInDataLen > (4096 * 1024)) // too much data in buffer (not reading)
 		{
-			callFunction(this,"disconnectEvent",new KviKvsVariantList(
-				new KviKvsVariant(__tr2qs_ctx("Too much unprocessed incoming data (you've left this socket unmanaged ?)","objects"))));
+			KviKvsVariantList lParams;
+			lParams.append(new KviKvsVariant(new KviKvsVariant(__tr2qs_ctx("Too much unprocessed incoming data (you've left this socket unmanaged ?)","objects"))));
+			callFunction(this,"disconnectEvent",&lParams);
 			reset();
 		}
 	}
@@ -1187,8 +1209,9 @@ void KviKvsObject_socket::tryFlush()
 		} else {
 			// Disconnected... :(
 			unsigned int uOldConnectionId = m_uConnectionId;
-			callFunction(this,"disconnectEvent",0,new KviKvsVariantList(
-				new KviKvsVariant(KviError::getDescription(KviError::translateSystemError(err)))));
+			KviKvsVariantList lParams;
+			lParams.append(new KviKvsVariant(KviError::getDescription(KviError::translateSystemError(err))));
+			callFunction(this,"disconnectEvent",&lParams);
 			if(m_uConnectionId == uOldConnectionId)reset();
 			// else it has already been called!
 			return;
