@@ -413,7 +413,7 @@ void KviTrayIcon::refresh()
 
 void KviTrayIcon::activatedSlot( QSystemTrayIcon::ActivationReason reason )
 {
-	if(reason==QSystemTrayIcon::Trigger)
+	if(reason==QSystemTrayIcon::Trigger && (KVI_OPTION_BOOL(KviOption_boolCloseInTray) || !m_pFrm->isVisible()))
 	{
 		toggleParentFrame();
 	}
@@ -461,9 +461,9 @@ void KviTrayIcon::grabActivityInfo()
 				break;
 			}
 		} else {
-			unsigned int iLevel=0;
 			if(b->kviWindow()->view())
 			{
+				unsigned int iLevel=0;
 				if(b->kviWindow()->view()->haveUnreadedHighlightedMessages())
 				{
 					iLevel=2;
